==> openGion_dev_5.9.8.0.zip: opengion/uap/webapps/ge/db/sqlserver/sql/install/01_TABLE/GEA05S.sql <==
/****************************************************************************/
/* GEA05 ( ﾛｰﾙﾏｽﾀ )                                                         */
/*                                                                          */
/* Created : 2015/12/01 16:54:32                                            */
/****************************************************************************/
CREATE TABLE GEA05 (
   SYSTEM_ID    varchar           (  10 )                   NOT NULL            /*  10 ｼｽﾃﾑID   */
 , ROLES        varchar           ( 500 )                   NOT NULL            /*  20 ﾛｰﾙｽﾞ    */
 , NMROLE       varchar           ( 200 )                                       /*  30 ﾛｰﾙ名称  */
 , KBROLE       varchar           (   1 )       DEFAULT 1   NOT NULL            /*  40 ﾛｰﾙ区分  */
 , UNIQ         int IDENTITY(1,1)                                               /* 800 ﾕﾆｰｸｷｰ   */
 , FGJ          varchar           (   1 )       DEFAULT 1   NOT NULL            /* 810 状態ﾌﾗｸﾞ */
 , DYSET        varchar           (  14 )                                       /* 820 登録日時 */
 , PGSET        varchar           (  10 )                                       /* 830 作成PG   */
 , PGPSET       varchar           (  10 )                                       /* 840 作成親PG */
 , USRSET       varchar           (  10 )                                       /* 850 作成社員 */
 , DYUPD        varchar           (  14 )                                       /* 860 更新日時 */
 , PGUPD        varchar           (  10 )                                       /* 870 更新PG   */
 , PGPUPD       varchar           (  10 )                                       /* 880 更新親PG */
 , USRUPD       varchar           (  10 )                                       /* 890 更新者   */
);

==> openGion_dev_5.9.19.0.zip: opengion/uap/webapps/ge/db/sqlserver/sql/install/01_TABLE/GEA05S.sql <==
/****************************************************************************/
/* GEA05 ( ﾛｰﾙﾏｽﾀ )                                                         */
/*                                                                          */
/* Created : 2017/04/07 09:50:28                                            */
/****************************************************************************/
CREATE TABLE GEA05 (
   SYSTEM_ID    varchar           (  10 )                   NOT NULL            /*  10 ｼｽﾃﾑID   */
 , ROLES        varchar           ( 500 )                   NOT NULL            /*  20 ﾛｰﾙｽﾞ    */
 , NMROLE       varchar           ( 200 )                                       /*  30 ﾛｰﾙ名称  */
 , KBROLE       varchar           (   1 )       DEFAULT '1' NOT NULL            /*  40 ﾛｰﾙ区分  */
 , UNIQ         int IDENTITY(1,1)                                               /* 800 ﾕﾆｰｸｷｰ   */
 , FGJ          varchar           (   1 )       DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ */
 , DYSET        varchar           (  14 )                                       /* 820 登録日時 */
 , PGSET        varchar           (  10 )                                       /* 830 作成PG   */
 , PGPSET       varchar           (  10 )                                       /* 840 作成親PG */
 , USRSET       varchar           (  10 )                                       /* 850 作成社員 */
 , DYUPD        varchar           (  14 )                                       /* 860 更新日時 */
 , PGUPD        varchar           (  10 )                                       /* 870 更新PG   */
 , PGPUPD       varchar           (  10 )                                       /* 880 更新親PG */
 , USRUPD       varchar           (  10 )                                       /* 890 更新者   */
);
